.. _api-backends:

vcs.backends
============

.. module:: vcs.backends

Implemented Backends
--------------------

.. toctree::
   :maxdepth: 1

   git
   hg

.. _api-base-backend:

Base Backend
------------

.. automodule:: vcs.backends.base
   :members:
